summaryrefslogtreecommitdiff
path: root/db/08to09_pg.sql
diff options
context:
space:
mode:
authorBrion Vibber <brion@pobox.com>2009-11-19 20:55:38 -0800
committerBrion Vibber <brion@pobox.com>2009-11-19 21:04:21 -0800
commitdd36c2de23dbdb30f333be1f9d5292d62363b0c8 (patch)
tree89eae38f77e74b51478cc2ec0c13a0ac249d75ba /db/08to09_pg.sql
parentdc90e90fd2748f953a2d4750105817b41cafe43a (diff)
Initial functional version of feed subscription plugin, currently supporting only PuSH-enabled feeds.
Diffstat (limited to 'db/08to09_pg.sql')
-rw-r--r--db/08to09_pg.sql6
1 files changed, 3 insertions, 3 deletions
diff --git a/db/08to09_pg.sql b/db/08to09_pg.sql
index d9b57fb84..7aaf3a7a0 100644
--- a/db/08to09_pg.sql
+++ b/db/08to09_pg.sql
@@ -29,13 +29,13 @@ create table config (
);
-create table user_role (
+create table profile_role (
- user_id integer not null /* comment 'user having the role'*/ references "user" (id),
+ profile_id integer not null /* comment 'account having the role'*/ references profile (id),
role varchar(32) not null /* comment 'string representing the role'*/,
created timestamp /* not null comment 'date the role was granted'*/,
- primary key (user_id, role)
+ primary key (profile_id, role)
);